@@ -5,7 +5,7 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Interp;
-
+$HTML::Mason::Interp::VERSION = '1.60';
 use strict;
 use warnings;
 
@@ -649,6 +649,7 @@ sub set_global
 
     my $varname = sprintf("%s::%s",$self->compiler->in_package,$name);
     no strict 'refs';
+    no warnings 'once';
     if ($prefix eq '$') {
         $$varname = $values[0];
     } elsif ($prefix eq '@') {
@@ -861,7 +862,7 @@ sub object_file {
 sub use_autohandlers
 {
     my $self = shift;
-    return defined $self->{autohandler_name} and length $self->{autohandler_name};
+    return (defined $self->{autohandler_name} and length $self->{autohandler_name});
 }
 
 # Generate HTML that describes Interp's current status.
@@ -1437,10 +1438,4 @@ C<strict>.
 
 =back
 
-=head1 SEE ALSO
-
-L<HTML::Mason|HTML::Mason>,
-L<HTML::Mason::Admin|HTML::Mason::Admin>,
-L<HTML::Mason::ApacheHandler|HTML::Mason::ApacheHandler>
-
 =cut
